import 'package:email_validator/email_validator.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:intl/intl.dart';


class InputHelper {

  static TextFormField input_string(
      String hint, TextEditingController controle, TextInputType type) {
    return TextFormField(
      inputFormatters: [
        FilteringTextInputFormatter.allow(RegExp('[a-z-A-Z ]')),
      ],
      controller: controle,
      validator: (String? value) {
        if (value == null) {
          return 'Campo Obrigatorio';
        }
      },
      keyboardType: type,
      textAlign: TextAlign.center,
      style: const TextStyle(
        color: Colors.white,
        fontSize: 18,
      ),
      decoration: InputDecoration(
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(15.0),
            borderSide: const BorderSide(
                width: 1.5, color: Color.fromARGB(255, 252, 182, 9))),
        filled: true,
        fillColor: Colors.black,
        hintStyle: const TextStyle(color: Colors.white),
        hintText: hint,
        contentPadding: const EdgeInsets.all(1),
      ),
    );
  }

  static TextFormField input_email(
      String hint, TextEditingController controle, TextInputType type) {
    return TextFormField(
      controller: controle,
      onChanged: (value) => {EmailValidator.validate(value)},
      keyboardType: type,
      textAlign: TextAlign.center,
      style: const TextStyle(
        color: Colors.white,
        fontSize: 18,
      ),
      decoration: InputDecoration(
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(15.0),
            borderSide: const BorderSide(
                width: 1.5, color: Color.fromARGB(255, 252, 182, 9))),
        filled: true,
        fillColor: Colors.black,
        hintStyle: const TextStyle(color: Colors.white),
        hintText: hint,
        contentPadding: const EdgeInsets.all(1),
      ),
    );
  }

  static TextFormField input_password(
      String hint, TextEditingController controle, TextInputType type) {
    return TextFormField(
      controller: controle,
      obscureText: true,
      keyboardType: type,
      validator: (String? value) {
        if (value == null) {
          return 'Campo Obrigatorio';
        }
      },
      textAlign: TextAlign.center,
      style: const TextStyle(
        color: Colors.white,
        fontSize: 18,
      ),
      decoration: InputDecoration(
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(15.0),
            borderSide: const BorderSide(
                width: 1.5, color: Color.fromARGB(255, 252, 182, 9))),
        filled: true,
        fillColor: Colors.black,
        hintStyle: const TextStyle(color: Colors.white),
        hintText: hint,
        contentPadding: const EdgeInsets.all(1),
      ),
    );
  }

  static TextFormField input_peso(
      String hint, TextEditingController controle, TextInputType type) {
    return TextFormField(
      inputFormatters: [
        FilteringTextInputFormatter.deny(RegExp('[0-9]{1,3}[.][0-9]{1}')),
      ],
      validator: (String? value) {
        if (value == null) {
          return 'Campo Obrigatorio';
        }
      },
      controller: controle,
      keyboardType: type,
      textAlign: TextAlign.center,
      style: const TextStyle(
        color: Colors.white,
        fontSize: 18,
      ),
      decoration: InputDecoration(
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(15.0),
            borderSide: const BorderSide(
                width: 1.5, color: Color.fromARGB(255, 252, 182, 9))),
        filled: true,
        fillColor: Colors.black,
        hintStyle: const TextStyle(color: Colors.white),
        hintText: hint,
        contentPadding: const EdgeInsets.all(1),
      ),
    );
  }

  static TextFormField input_altura(
      String hint, TextEditingController controle, TextInputType type) {
    return TextFormField(
      keyboardType: type,
      inputFormatters: [
        FilteringTextInputFormatter.deny(RegExp('[0-9]{1}[.][0-9]{2}')),
      ],
      controller: controle,
      validator: (String? value) {
        if (value == null) {
          return 'Campo Obrigatorio';
        }
      },
      textAlign: TextAlign.center,
      style: const TextStyle(
        color: Colors.white,
        fontSize: 18,
      ),
      decoration: InputDecoration(
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(15.0),
            borderSide: const BorderSide(
                width: 1.5, color: Color.fromARGB(255, 252, 182, 9))),
        filled: true,
        fillColor: Colors.black,
        hintStyle: const TextStyle(color: Colors.white),
        hintText: hint,
        contentPadding: const EdgeInsets.all(1),
      ),
    );
  }

  static DropdownButtonFormField drpBtn(
      String opt1, String opt2, String opt3, TextEditingController controle) {
    return DropdownButtonFormField(
      dropdownColor: Color.fromARGB(255, 252, 182, 9),
      style: TextStyle(color: Colors.white, fontSize: 18),
      decoration: InputDecoration(
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(15.0),
            borderSide: const BorderSide(
                width: 1.5, color: Color.fromARGB(255, 252, 182, 9))),
        filled: true,
        fillColor: Colors.black,
        hintStyle: const TextStyle(color: Colors.white),
        hintText: "                         PERNA DOMINANTE",
        contentPadding: const EdgeInsets.all(1),
      ),
      items: [
        DropdownMenuItem(
          child: Text(opt1),
          value: opt1,
        ),
        DropdownMenuItem(
          child: Text(opt2),
          value: opt2,
        ),
        DropdownMenuItem(
          child: Text(opt3),
          value: opt3,
        ),
      ],
      onChanged: (value) => controle,
      isExpanded: true,
    );
  }

  static DropdownButtonFormField drpBtnEstados(TextEditingController controle) {
    return DropdownButtonFormField(      
      dropdownColor: Color.fromARGB(255, 252, 182, 9),
      style: TextStyle(color: Colors.white, fontSize: 18),
      decoration: InputDecoration(
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(15.0),
            borderSide: const BorderSide(
                width: 1.5, color: Color.fromARGB(255, 252, 182, 9))),
        filled: true,
        fillColor: Colors.black,
        hintStyle: const TextStyle(color: Colors.white),
        hintText: "            ESTADO",
        contentPadding: const EdgeInsets.all(1),
      ),
      items: [
        DropdownMenuItem(
          child: Text("Acre"),
          value: "AC",
        ),
        DropdownMenuItem(
          child: Text("Alagoas"),
          value: "AL",
        ),
        DropdownMenuItem(
          child: Text("Amapá"),
          value: "AP",
        ),
        DropdownMenuItem(
          child: Text("Amazonas"),
          value: "AM",
        ),
        DropdownMenuItem(
          child: Text("Bahia"),
          value: "BA",
        ),
        DropdownMenuItem(
          child: Text("Ceará"),
          value: "CE",
        ),
        DropdownMenuItem(
          child: Text("Distrito Federal"),
          value: "DF",
        ),
        DropdownMenuItem(
          child: Text("Espírito Santo "),
          value: "ES",
        ),
        DropdownMenuItem(
          child: Text("Goiás"),
          value: "GO",
        ),
        DropdownMenuItem(
          child: Text("Maranhão"),
          value: "MA",
        ),
        DropdownMenuItem(
          child: Text("Mato Grosso"),
          value: "MT",
        ),
        DropdownMenuItem(
          child: Text("Mato Grosso do Sul"),
          value: "MS",
        ),
        DropdownMenuItem(
          child: Text("Minas Gerais"),
          value: "MG",
        ),
        DropdownMenuItem(
          child: Text("Pará"),
          value: "PR",
        ),
        DropdownMenuItem(
          child: Text("Paraíba"),
          value: "PB",
        ),
        DropdownMenuItem(
          child: Text("Paraná"),
          value: "PR",
        ),
        DropdownMenuItem(
          child: Text("Pernambuco"),
          value: "PE",
        ),
        DropdownMenuItem(
          child: Text("Piauí"),
          value: "PI",
        ),
        DropdownMenuItem(
          child: Text("Rio de Janeiro"),
          value: "RJ",
        ),
        DropdownMenuItem(
          child: Text("Rio Grande do Norte"),
          value: "RN",
        ),
        DropdownMenuItem(
          child: Text("Rio Grande do Sul"),
          value: "RS",
        ),
        DropdownMenuItem(
          child: Text("Rondônia"),
          value: "RO",
        ),
        DropdownMenuItem(
          child: Text("Roraima"),
          value: "RR",
        ),
        DropdownMenuItem(
          child: Text("Santa Catarina"),
          value: "SC",
        ),
        DropdownMenuItem(
          child: Text("São Paulo"),
          value: "SP",
        ),
        DropdownMenuItem(
          child: Text("Sergipe"),
          value: "SE",
        ),
        DropdownMenuItem(
          child: Text("Tocantins"),
          value: "TO",
        ),
      ],
      onChanged: (value) => controle,
      isExpanded: true,
    );
  }
}
