import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:joinfut/helpers/input_helper.dart';
import 'package:joinfut/models/PlayerModel.dart';
import 'package:intl/intl.dart';
import 'package:joinfut/models/PlayerModel.dart';

import '../services/PlayerService.dart';

class PlayerRegisterPage extends StatefulWidget {
  const PlayerRegisterPage({super.key});

  @override
  _PlayerRegisterPage createState() => _PlayerRegisterPage();
}

class _PlayerRegisterPage extends State<PlayerRegisterPage> {
  DateTime? _dateTime;

  final _formKey = GlobalKey<FormState>();

  final _name = TextEditingController();
  final _birth = TextEditingController();
  final _height = TextEditingController();
  final _weight = TextEditingController();
  final _bid = TextEditingController();
  final _leg = TextEditingController();
  final _position = TextEditingController();
  final _playStyle = TextEditingController();
  final _medicalIssues = TextEditingController();
  final _adress = TextEditingController();
  final _adressCity = TextEditingController();
  final _adressStd = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      body: SingleChildScrollView(
        child: Form(
            key: _formKey,
            child: Padding(
              padding: const EdgeInsets.all(25.0),
              child: Column(
                children: [
                  const SizedBox(height: 50),
                  SizedBox(
                      child: Image.asset('assets/images/logo_appbar.jpg',
                          height: 100, fit: BoxFit.contain)),
                  const SizedBox(height: 50),
                  SizedBox(
                      height: 35,
                      child: InputHelper.input_string(
                        "NOME",
                        _name,
                        TextInputType.text,
                      )),
                  const SizedBox(height: 7),
                  SizedBox(
                      height: 35,
                      child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Container(
                              width: 172,
                              height: 35,
                              alignment: Alignment.center,
                              decoration: BoxDecoration(
                                color: Colors.black,
                                border: Border.all(
                                    color: Color.fromARGB(255, 252, 182, 9),
                                    width: 1.5),
                                borderRadius: BorderRadius.circular(50.0),
                              ),
                              child: Text(
                                _dateTime == null
                                    ? 'NASCIMENTO'
                                    : '${_dateTime!.year}/${_dateTime?.month}/${_dateTime?.day}',
                                style: TextStyle(
                                    color: Colors.white, fontSize: 17),
                              ),
                            ),
                            SizedBox(
                              width: 10,
                            ),
                            ElevatedButton(
                              style: ElevatedButton.styleFrom(
                                primary: Color.fromARGB(255, 252, 182, 9),
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(50),
                                ),
                              ),
                              child: Text('Selecione a Data',
                                  style: TextStyle(
                                      color: Colors.black, fontSize: 17)),
                              onPressed: () async {
                                showDatePicker(
                                        context: context,
                                        initialDate:
                                            _dateTime ?? DateTime.now(),
                                        firstDate: DateTime(1900),
                                        lastDate: DateTime.now())
                                    .then((date) {
                                  setState(() {
                                    _dateTime = date!;
                                  });
                                });
                              },
                            )
                          ])),
                  const SizedBox(height: 7),
                  SizedBox(
                    height: 35,
                    child: Row(
                      children: [
                        Expanded(
                            child: InputHelper.input_peso(
                                "PESO", _weight, TextInputType.number)),
                        const SizedBox(
                          width: 10,
                        ),
                        Expanded(
                            child: InputHelper.input_altura(
                                "ALTURA", _height, TextInputType.number)),
                      ],
                    ),
                  ),
                  const SizedBox(
                    height: 7,
                  ),
                  SizedBox(
                      height: 35,
                      child: InputHelper.input_string(
                          "POSIÇÃO", _position, TextInputType.text)),
                  const SizedBox(
                    height: 7,
                  ),
                  SizedBox(
                      height: 35,
                      child: InputHelper.drpBtn(
                          "Ambidestro", "Direita", "Esquerda", _leg)),
                  const SizedBox(
                    height: 7,
                  ),
                  SizedBox(
                      height: 35,
                      child: InputHelper.input_string("DOENÇAS PRÉ-EXISTENTES?",
                          _medicalIssues, TextInputType.text)),
                  const SizedBox(
                    height: 7,
                  ),
                  SizedBox(
                      height: 35,
                      child: InputHelper.input_string(
                          "CÓDIGO BID (OPCIONAL)", _bid, TextInputType.number)),
                  const SizedBox(
                    height: 7,
                  ),
                  SizedBox(
                      height: 35,
                      child: InputHelper.input_string(
                          "ENDEREÇO", _adress, TextInputType.text)),
                  const SizedBox(height: 7),
                  SizedBox(
                    height: 35,
                    child: Row(
                      children: [
                        Expanded(
                            child: InputHelper.input_string(
                                "CIDADE", _adressCity, TextInputType.text)),
                        const SizedBox(width: 10),
                        Expanded(child: InputHelper.drpBtnEstados(_adressStd)),
                      ],
                    ),
                  ),
                  const SizedBox(
                    height: 20,
                  ),
                  Container(
                    alignment: Alignment.center,
                    child: const Text(
                      "TERMO DE CONSCENTIMENTO DE CONCESSÃO DE DADOS",
                      style: TextStyle(color: Colors.white),
                      textAlign: TextAlign.center,
                    ),
                  ),
                  ElevatedButton(
                    style: ElevatedButton.styleFrom(
                      primary: Color.fromARGB(255, 252, 182, 9),
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(50),
                      ),
                    ),
                    onPressed: () {
                      registerPlayer();
                    },
                    child: const Text(
                      "Criar Usuário",
                      style: const TextStyle(color: Colors.black, fontSize: 17),
                    ),
                  ),
                ],
              ),
            )),
      ),
    );
  }

  void registerPlayer() {
    PlayerModel playerModel = getPlayerModel();
    PlayerService service = new PlayerService();
    //service.postPlayer(playerModel);
    Future<PlayerModel> pm = service.getPlayer(11);
    print(pm);
  }

  PlayerModel getPlayerModel() {
    PlayerModel playerModel = PlayerModel(
      atleteName: _name.text, 
      atleteHeight: _height.text, 
      atleteWeight: _weight.text,
      atleteBid: _bid.text,
      adress: _adress.text,
      dominantLeg: 'L',
      position: _position.text,
      medicalIssues: _medicalIssues.text,
      adressCity: _adressCity.text,
      adressState: "RS"
    );

    return playerModel;
  }
}
